@@ -1,8 +1,8 @@
 
-version = '3.4.0'
+version = '3.12.0.post2'
 major = 3
-minor = 4
+minor = 12
 micro = 0
-release_level = 'final'
-serial = 0
+release_level = 'post'
+serial = 2
 version_info = (major, minor, micro, release_level, serial)
